<#
	.SYNOPSIS
		Checks availability of needed Windows Features for IIS
	
#>

[CmdletBinding(SupportsShouldProcess=$true)]
Param (
    # GENERIC PARAMETERS
    # ------------------
   	[Parameter(Mandatory=$false,HelpMessage="Try to install missing features")]
    [switch] $InstallMissingFeatures
)	

Function CheckWindowsFeature()
{
[CmdletBinding(SupportsShouldProcess=$true)]
Param (
    # GENERIC PARAMETERS
    # ------------------
    [Parameter(Mandatory=$true,HelpMessage="Provide the name of the feature.")]
    [string] $feature)

    if (Get-WindowsFeature | Where-Object {($_.Name.Trim() -eq $feature) -and ($_.Installed -eq $True)})
		{	
			Write-Host "Feature: $($feature) installed." -ForegroundColor Green			
		}
		else
		{
			Write-Host "Feature: $($feature) not installed." -ForegroundColor Red			
            if($InstallMissingFeatures)
            {
                Add-WindowsFeature $feature
            }
		}

}



if (Get-Module -ListAvailable | where { $_.Name -eq "ServerManager"})
{
	Import-Module ServerManager -ErrorAction Stop
    Write-Host "Server Manager found!" -ForegroundColor Green
}
else
{
	Write-Host "Error while loading ServerManager, possibly running on Client OS" -ForegroundColor Red
	Exit 1
}

$iisInfo = Get-ItemProperty HKLM:\SOFTWARE\Microsoft\InetStp\
$version = [int]"$($iisInfo.MajorVersion)"

Write-Host $version

switch ($version) 
{
    10
    {        
        CheckWindowsFeature -feature Web-Server
        CheckWindowsFeature -feature Web-WebServer 
        CheckWindowsFeature -feature Web-ASP
        CheckWindowsFeature -feature Web-Asp-Net
        CheckWindowsFeature -feature Web-Asp-Net45
        CheckWindowsFeature -feature Web-Net-Ext
        CheckWindowsFeature -feature Web-Net-Ext45
        CheckWindowsFeature -feature Web-Scripting-Tools
        CheckWindowsFeature -feature Web-Common-Http
        CheckWindowsFeature -feature Web-Mgmt-Console
    }

    8
    {
        CheckWindowsFeature -feature Web-Common-Http
        CheckWindowsFeature -feature Web-Asp-Net
        CheckWindowsFeature -feature Web-Net-Ext
        CheckWindowsFeature -feature Web-ISAPI-Ext
        CheckWindowsFeature -feature Web-ISAPI-Filter
        CheckWindowsFeature -feature Web-Http-Logging
        CheckWindowsFeature -feature Web-Request-Monitor
        CheckWindowsFeature -feature Web-Basic-Auth
        CheckWindowsFeature -feature Web-Windows-Auth
        CheckWindowsFeature -feature Web-Filtering
        CheckWindowsFeature -feature Web-Performance
        CheckWindowsFeature -feature Web-Mgmt-Console
        CheckWindowsFeature -feature WAS
        CheckWindowsFeature -feature Web-Net-Ext45
        CheckWindowsFeature -feature Web-Asp-Net45
        CheckWindowsFeature -feature Web-Scripting-Tools
        CheckWindowsFeature -feature NET-Framework-Features
        CheckWindowsFeature -feature NET-Framework-45-Features
    }
}
# SIG # Begin signature block
# MIIYCgYJKoZIhvcNAQcCoIIX+zCCF/cCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQU08qKbrlp4vUQAPsUZRMEOuU6
# FEqgghMYMIID7jCCA1egAwIBAgIQfpPr+3zGTlnqS5p31Ab8OzANBgkqhkiG9w0B
# AQUFADCBizELMAkGA1UEBhMCWkExFTATBgNVBAgTDFdlc3Rlcm4gQ2FwZTEUMBIG
# A1UEBxMLRHVyYmFudmlsbGUxDzANBgNVBAoTBlRoYXd0ZTEdMBsGA1UECxMUVGhh
# d3RlIENlcnRpZmljYXRpb24xHzAdBgNVBAMTFlRoYXd0ZSBUaW1lc3RhbXBpbmcg
# Q0EwHhcNMTIxMjIxMDAwMDAwWhcNMjAxMjMwMjM1OTU5WjBeMQswCQYDVQQGEwJV
# UzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xMDAuBgNVBAMTJ1N5bWFu
# dGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EgLSBHMjCCASIwDQYJKoZIhvcN
# AQEBBQADggEPADCCAQoCggEBALGss0lUS5ccEgrYJXmRIlcqb9y4JsRDc2vCvy5Q
# WvsUwnaOQwElQ7Sh4kX06Ld7w3TMIte0lAAC903tv7S3RCRrzV9FO9FEzkMScxeC
# i2m0K8uZHqxyGyZNcR+xMd37UWECU6aq9UksBXhFpS+JzueZ5/6M4lc/PcaS3Er4
# ezPkeQr78HWIQZz/xQNRmarXbJ+TaYdlKYOFwmAUxMjJOxTawIHwHw103pIiq8r3
# +3R8J+b3Sht/p8OeLa6K6qbmqicWfWH3mHERvOJQoUvlXfrlDqcsn6plINPYlujI
# fKVOSET/GeJEB5IL12iEgF1qeGRFzWBGflTBE3zFefHJwXECAwEAAaOB+jCB9zAd
# BgNVHQ4EFgQUX5r1blzMzHSa1N197z/b7EyALt0wMgYIKwYBBQUHAQEEJjAkMCIG
# CCsGAQUFBzABhhZodHRwOi8vb2NzcC50aGF3dGUuY29tMBIGA1UdEwEB/wQIMAYB
# Af8CAQAwPwYDVR0fBDgwNjA0oDKgMIYuaHR0cDovL2NybC50aGF3dGUuY29tL1Ro
# YXd0ZVRpbWVzdGFtcGluZ0NBLmNybDATBgNVHSUEDDAKBggrBgEFBQcDCDAOBgNV
# HQ8BAf8EBAMCAQYwKAYDVR0RBCEwH6QdMBsxGTAXBgNVBAMTEFRpbWVTdGFtcC0y
# MDQ4LTEwDQYJKoZIhvcNAQEFBQADgYEAAwmbj3nvf1kwqu9otfrjCR27T4IGXTdf
# plKfFo3qHJIJRG71betYfDDo+WmNI3MLEm9Hqa45EfgqsZuwGsOO61mWAK3ODE2y
# 0DGmCFwqevzieh1XTKhlGOl5QGIllm7HxzdqgyEIjkHq3dlXPx13SYcqFgZepjhq
# IhKjURmDfrYwggSjMIIDi6ADAgECAhAOz/Q4yP6/NW4E2GqYGxpQMA0GCSqGSIb3
# DQEBBQUAMF4xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3Jh
# dGlvbjEwMC4GA1UEAxMnU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBD
# QSAtIEcyMB4XDTEyMTAxODAwMDAwMFoXDTIwMTIyOTIzNTk1OVowYjELMAkGA1UE
# BhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMTQwMgYDVQQDEytT
# eW1hbnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIFNpZ25lciAtIEc0MIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAomMLOUS4uyOnREm7Dv+h8GEKU5Ow
# mNutLA9KxW7/hjxTVQ8VzgQ/K/2plpbZvmF5C1vJTIZ25eBDSyKV7sIrQ8Gf2Gi0
# jkBP7oU4uRHFI/JkWPAVMm9OV6GuiKQC1yoezUvh3WPVF4kyW7BemVqonShQDhfu
# ltthO0VRHc8SVguSR/yrrvZmPUescHLnkudfzRC5xINklBm9JYDh6NIipdC6Anqh
# d5NbZcPuF3S8QYYq3AhMjJKMkS2ed0QfaNaodHfbDlsyi1aLM73ZY8hJnTrFxeoz
# C9Lxoxv0i77Zs1eLO94Ep3oisiSuLsdwxb5OgyYI+wu9qU+ZCOEQKHKqzQIDAQAB
# o4IBVzCCAVMwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDAO
# BgNVHQ8BAf8EBAMCB4AwcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRw
# Oi8vdHMtb2NzcC53cy5zeW1hbnRlYy5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90
# cy1haWEud3Muc3ltYW50ZWMuY29tL3Rzcy1jYS1nMi5jZXIwPAYDVR0fBDUwMzAx
# oC+gLYYraHR0cDovL3RzLWNybC53cy5zeW1hbnRlYy5jb20vdHNzLWNhLWcyLmNy
# bDAoBgNVHREEITAfpB0wGzEZMBcGA1UEAxMQVGltZVN0YW1wLTIwNDgtMjAdBgNV
# HQ4EFgQURsZpow5KFB7VTNpSYxc/Xja8DeYwHwYDVR0jBBgwFoAUX5r1blzMzHSa
# 1N197z/b7EyALt0wDQYJKoZIhvcNAQEFBQADggEBAHg7tJEqAEzwj2IwN3ijhCcH
# bxiy3iXcoNSUA6qGTiWfmkADHN3O43nLIWgG2rYytG2/9CwmYzPkSWRtDebDZw73
# BaQ1bHyJFsbpst+y6d0gxnEPzZV03LZc3r03H0N45ni1zSgEIKOq8UvEiCmRDoDR
# EfzdXHZuT14ORUZBbg2w6jiasTraCXEQ/Bx5tIB7rGn0/Zy2DBYr8X9bCT2bW+IW
# yhOBbQAuOA2oKY8s4bL0WqkBrxWcLC9JG9siu8P+eJRRw4axgohd8D20UaF5Mysu
# e7ncIAkTcetqGVvP6KUwVyyJST+5z3/Jvz4iaGNTmr1pdKzFHTx/kuDDvBzYBHUw
# ggUwMIIEGKADAgECAhAECRgbX9W7ZnVTQ7VvlVAIMA0GCSqGSIb3DQEBCwUAMGUx
# CzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3
# dy5kaWdpY2VydC5jb20xJDAiBgNVBAMTG0RpZ2lDZXJ0IEFzc3VyZWQgSUQgUm9v
# dCBDQTAeFw0xMzEwMjIxMjAwMDBaFw0yODEwMjIxMjAwMDBaMHIxCzAJBgNVBAYT
# AlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2Vy
# dC5jb20xMTAvBgNVBAMTKERpZ2lDZXJ0IFNIQTIgQXNzdXJlZCBJRCBDb2RlIFNp
# Z25pbmcgQ0EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD407Mcfw4R
# r2d3B9MLMUkZz9D7RZmxOttE9X/lqJ3bMtdx6nadBS63j/qSQ8Cl+YnUNxnXtqrw
# nIal2CWsDnkoOn7p0WfTxvspJ8fTeyOU5JEjlpB3gvmhhCNmElQzUHSxKCa7JGnC
# wlLyFGeKiUXULaGj6YgsIJWuHEqHCN8M9eJNYBi+qsSyrnAxZjNxPqxwoqvOf+l8
# y5Kh5TsxHM/q8grkV7tKtel05iv+bMt+dDk2DZDv5LVOpKnqagqrhPOsZ061xPeM
# 0SAlI+sIZD5SlsHyDxL0xY4PwaLoLFH3c7y9hbFig3NBggfkOItqcyDQD2RzPJ6f
# pjOp/RnfJZPRAgMBAAGjggHNMIIByTASBgNVHRMBAf8ECDAGAQH/AgEAMA4GA1Ud
# DwEB/wQEAwIBhjATBgNVHSUEDDAKBggrBgEFBQcDAzB5BggrBgEFBQcBAQRtMGsw
# JAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBDBggrBgEFBQcw
# AoY3aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElE
# Um9vdENBLmNydDCBgQYDVR0fBHoweDA6oDigNoY0aHR0cDovL2NybDQuZGlnaWNl
# cnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNybDA6oDigNoY0aHR0cDov
# L2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNybDBP
# BgNVHSAESDBGMDgGCmCGSAGG/WwAAgQwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93
# d3cuZGlnaWNlcnQuY29tL0NQUzAKBghghkgBhv1sAzAdBgNVHQ4EFgQUWsS5eyoK
# o6XqcQPAYPkt9mV1DlgwHwYDVR0jBBgwFoAUReuir/SSy4IxLVGLp6chnfNtyA8w
# DQYJKoZIhvcNAQELBQADggEBAD7sDVoks/Mi0RXILHwlKXaoHV0cLToaxO8wYdd+
# C2D9wz0PxK+L/e8q3yBVN7Dh9tGSdQ9RtG6ljlriXiSBThCk7j9xjmMOE0ut119E
# efM2FAaK95xGTlz/kLEbBw6RFfu6r7VRwo0kriTGxycqoSkoGjpxKAI8LpGjwCUR
# 4pwUR6F6aGivm6dcIFzZcbEMj7uo+MUSaJ/PQMtARKUT8OZkDCUIQjKyNookAv4v
# cn4c10lFluhZHen6dGRrsutmQ9qzsIzV6Q3d9gEgzpkxYz0IGhizgZtPxpMQBvwH
# gfqL2vmCSfdibqFT+hKUGIUukpHqaGxEMrJmoecYpJpkUe8wggVHMIIEL6ADAgEC
# AhAJuusgebwwEtPQbVTZm2PQMA0GCSqGSIb3DQEBCwUAMHIxCzAJBgNVBAYTAlVT
# MRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5j
# b20xMTAvBgNVBAMTKERpZ2lDZXJ0IFNIQTIgQXNzdXJlZCBJRCBDb2RlIFNpZ25p
# bmcgQ0EwHhcNMTcwNzEzMDAwMDAwWhcNMjAxMDAzMTIwMDAwWjCBgzELMAkGA1UE
# BhMCQ0gxFDASBgNVBAcTC1N0ZWluaGF1c2VuMS4wLAYDVQQKDCVCcmFpbldhcmUg
# Q29uc3VsdGluZyAmIERldmVsb3BtZW50IEFHMS4wLAYDVQQDDCVCcmFpbldhcmUg
# Q29uc3VsdGluZyAmIERldmVsb3BtZW50IEFHMIIBIjANBgkqhkiG9w0BAQEFAAOC
# AQ8AMIIBCgKCAQEAwYXJaw9FYuE0MwZ9SeVwDYUEMV27pGInQmG3ciRt4L9Amu7K
# QsBkCZ5mT5dmOOQeDMN0moJrkcWzr4pc20rtOWYzXkffgygFBuDfw3nz2Zb6BiJj
# yQrcX26OiJ9BaFh9o30e+T6C8dQnbln75M6BrltBMgDhBw2B8lBFnOyh4KXS2ddJ
# 4j0XxClSogCZUw/VWeeVLbtWfGgVKJa2i3g+LjuuNWx6pTYAbo2+Lo8AvVzv+VMY
# 4YB88LJzBhA223sSaYzihD6A2alDqm7XWNA6eHbKh5lpCv+l+IEjAaYgP0g5OkLR
# 4g9ENWofy9AJnqOcABNlQLqanO2qO117jWAOswIDAQABo4IBxTCCAcEwHwYDVR0j
# BBgwFoAUWsS5eyoKo6XqcQPAYPkt9mV1DlgwHQYDVR0OBBYEFLQ8iOCed92oFS9G
# kdWVNOnJdYANMA4GA1UdDwEB/wQEAwIHgDATBgNVHSUEDDAKBggrBgEFBQcDAzB3
# BgNVHR8EcDBuMDWgM6Axhi9odHRwOi8vY3JsMy5kaWdpY2VydC5jb20vc2hhMi1h
# c3N1cmVkLWNzLWcxLmNybDA1oDOgMYYvaHR0cDovL2NybDQuZGlnaWNlcnQuY29t
# L3NoYTItYXNzdXJlZC1jcy1nMS5jcmwwTAYDVR0gBEUwQzA3BglghkgBhv1sAwEw
# KjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzAIBgZn
# gQwBBAEwgYQGCCsGAQUFBwEBBHgwdjAkBggrBgEFBQcwAYYYaHR0cDovL29jc3Au
# ZGlnaWNlcnQuY29tME4GCCsGAQUFBzAChkJodHRwOi8vY2FjZXJ0cy5kaWdpY2Vy
# dC5jb20vRGlnaUNlcnRTSEEyQXNzdXJlZElEQ29kZVNpZ25pbmdDQS5jcnQwDAYD
# VR0TAQH/BAIwADANBgkqhkiG9w0BAQsFAAOCAQEAGGD+KzDLlG9bV/tTlJEVYud0
# 3coiRNThlYUfcnIz5bHwekrf+E3q41tOFdw+i5NmI3Df1H/vUWWeJ2HmlIYT5enA
# vWOen8xJt6h/rncsHAKn1hMsSeMIP0vKD5UhDQ+DymwO2leND3FFNiMu8SBBt/K4
# 1PELFLOCM5IRBWnob2o3Fpkw+PRlI5DVThz9pddDH5UL3jNQPI5tm1vtQigFh7xo
# dng8R6k6ikdAnaotoAulcyQlLn90XSBEWvpD1HChfZ9BveNm35KnnSTJCZ0VaaVj
# XehvI8K1XqpHDqeGWWYUIgFLD3mc6cUTfKUWrMJQt2Ekln+1pTHtqY30hRoLkTGC
# BFwwggRYAgEBMIGGMHIxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJ
# bmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xMTAvBgNVBAMTKERpZ2lDZXJ0
# IFNIQTIgQXNzdXJlZCBJRCBDb2RlIFNpZ25pbmcgQ0ECEAm66yB5vDAS09BtVNmb
# Y9AwCQYFKw4DAhoFAKCBnDAZBgkqhkiG9w0BCQMxDAYKKwYBBAGCNwIBBDAcBgor
# BgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkqhkiG9w0BCQQxFgQUU+4/3gnG
# TGlFrxnEncfNxJTJE6IwPAYKKwYBBAGCNwIBDDEuMCygKoAoAEkASQBTAFAAcgBl
# AHIAZQBxAHUAaQBzAGkAdABlAHMALgBwAHMAMTANBgkqhkiG9w0BAQEFAASCAQB9
# M9Ll+O7PRXkPVbHPwN4/IbWtNfuXuyFFOSuchvqerFz7QBy+Vv/oAZul4uIYG5I9
# VejE3xs8CALb42lQyK73kIbEOvYcmyV2y/9T/sMT0g0j98XHzoAOpv30b7tPvF/s
# cD2ZV1hqyrDGPwqPNbUWkJPcXsOQz+4C3tMVDTzgHrDweKyRgvG3wktyUo9kcxR4
# ZkgtqCDYvAgdLfz3g85HyoQrPSKdMh4i6h7nyYT/3wpZe9+swwXIxCSYnGpT/BjQ
# Vcd7ygeAw79yR4y72nONQLdGgxUiwRqX3CI+olZ3Q3By0yn30R8h2TaXtUl+9KDP
# GPcbE8QrcN2g8aH8BnbToYICCzCCAgcGCSqGSIb3DQEJBjGCAfgwggH0AgEBMHIw
# XjELMAkGA1UEBhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMTAw
# LgYDVQQDEydTeW1hbnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIENBIC0gRzIC
# EA7P9DjI/r81bgTYapgbGlAwCQYFKw4DAhoFAKBdMBgGCSqGSIb3DQEJAzELBgkq
# hkiG9w0BBwEwHAYJKoZIhvcNAQkFMQ8XDTIwMDYyNTEwNDYxMFowIwYJKoZIhvcN
# AQkEMRYEFEHmCo4tKiv/rriO8QiYdcbc2mI/MA0GCSqGSIb3DQEBAQUABIIBACh1
# cUTR4/xOPsJ5kEouZUGXjwJLLMqVFiN64fo9zhRFNopZ5ez6nRwW/JMIEW/1JqV6
# XNkb91djBOuGdf2jVd/4Kn5R+B+YQ9C3uNgvMGz2tJhQZlBQgOvgZzp5SniRz3Ut
# ItgF3l/bXfTiAUO5jUIIRqW3NKxct/oXvZRMpmy5Pp8UcEN51+mi+oRM/BeM94PE
# AmpADlATkAC11xMawldITIo8DHtIuXynFtSSPnP03XlAY6QXfbWgmMkFCL27n9r9
# rJoWF/u23di+PijVhBIer2V2dbyjt/nr/Ix8KLQjrxba5fjBB1vH+LTfOoK8KTJd
# E2m6S3n/LqQFV3ZfLL0=
# SIG # End signature block
